@@ -1,6 +1,7 @@
 """Shared functionality between library albums, extras, and tracks."""
 
 from pathlib import Path
+from typing import Tuple
 
 import sqlalchemy
 
@@ -15,6 +16,10 @@ class LibItem:
         """A library item's filesystem path."""
         raise NotImplementedError
 
+    def fields(self) -> Tuple[str, ...]:
+        """Returns the public attributes of an item."""
+        raise NotImplementedError
+
 
 class PathType(sqlalchemy.types.TypeDecorator):
     """A custom type for paths for database storage.
