@@ -1,12 +1,27 @@
-"""Alters the location of files in your library.
+"""Alters the location of items in your library.
 
-The `move` plugin provides the following features:
- * ``move`` command to "consolidate" or move items in the library to reflect changes in
-    your configuration or tags.
- * Any items added to the library will be copied to the location set by
-    ``library_path`` in your configuration file.
+The ``move`` plugin provides the following features:
 
-This plugin is enabled by default.
+* Any items added to your library will be copied to the location set by ``library_path``
+  in your configuration file.
+* Any items moved or copied will have their paths set to a default format.
+  This default format cannot currently be configured, and is as follows:
+
+  * Albums: ``{library_path}/{albumartist} ({album_year})/``
+  * Tracks: ``{album_path}/{track_number} - {track_title}.{file_ext}``
+
+    If the album contains more than one disc, tracks will be formatted as:
+
+    ``{album_path}/Disc {disc#}/{track_number} - {track_title}.{file_ext}``
+  * Extras: ``{album_path}/{original_file_name}``
+
+API:
+    This plugin provides an interface for automatically formatting item paths as
+    specified above via ``fmt_item_path()``, moving items with ``move_item()``,
+    and copying items with ``copy_item()``.
+
+Note:
+    This plugin is enabled by default.
 """
 
 import argparse
@@ -14,7 +29,7 @@ import logging
 import shutil
 from contextlib import suppress
 from pathlib import Path
-from typing import List
+from typing import Union
 
 import dynaconf
 import sqlalchemy as sa
@@ -25,9 +40,10 @@ import moe
 from moe.core.config import Config
 from moe.core.library.album import Album
 from moe.core.library.extra import Extra
+from moe.core.library.lib_item import LibItem
 from moe.core.library.track import Track
 
-__all__: List[str] = []
+__all__ = ["fmt_item_path", "copy_item", "move_item"]
 
 log = logging.getLogger("moe.move")
 
@@ -81,7 +97,7 @@ def _parse_args(
     if args.dry_run:
         dry_run_str = ""
         for dry_album in albums:
-            album_dest = _fmt_album_path(dry_album, config)
+            album_dest = fmt_item_path(dry_album, config)
             if album_dest != dry_album.path:
                 dry_run_str += f"\n{dry_album.path}\n\t-> {album_dest}"
 
@@ -90,11 +106,11 @@ def _parse_args(
             sa.orm.attributes.set_committed_value(dry_album, "path", album_dest)
 
             for dry_track in dry_album.tracks:
-                track_dest = _fmt_track_path(dry_track, config)
+                track_dest = fmt_item_path(dry_track, config)
                 if track_dest != dry_track.path:
                     dry_run_str += f"\n{dry_track.path}\n\t-> {track_dest}"
             for dry_extra in dry_album.extras:
-                extra_dest = _fmt_extra_path(dry_extra, config)
+                extra_dest = fmt_item_path(dry_extra, config)
                 if extra_dest != dry_extra.path:
                     dry_run_str += f"\n{dry_extra.path}\n\t-> {extra_dest}"
 
@@ -102,18 +118,47 @@ def _parse_args(
             print(dry_run_str.lstrip())  # noqa: WPS421
     else:
         for album in albums:
-            _move_album(album, _fmt_album_path(album, config), config)
+            move_item(album, config)
 
 
-@moe.hookimpl(trylast=True)
-def pre_add(config: Config, session: Session, album: Album):
-    """Copies and formats the path of an album prior to it being added."""
-    _copy_album(album, _fmt_album_path(album, config), config)
+@moe.hookimpl
+def post_add(config: Config, session: Session, item: LibItem):
+    """Copies and formats the path of an item after it has been added to the library."""
+    # copy the whole album in case album attributes have changed
+    if isinstance(item, Album):
+        album = item
+    elif isinstance(item, (Extra, Track)):
+        album = item.album_obj
+
+    copy_item(album, config)
 
 
 ########################################################################################
 # Format paths
 ########################################################################################
+def fmt_item_path(item: LibItem, config: Config) -> Path:
+    """Returns a formatted item path according to the user configuration.
+
+    Args:
+        item: Library item used to format the directory.
+        config: Moe config.
+
+    Returns:
+        Formatted item path under the config ``library_path``.
+    """
+    if isinstance(item, Album):
+        new_path = _fmt_album_path(item, config)
+    elif isinstance(item, Extra):
+        new_path = _fmt_extra_path(item, config)
+    elif isinstance(item, Track):
+        new_path = _fmt_track_path(item, config)
+
+    if config.settings.move.asciify_paths:
+        new_path = Path(unidecode(str(new_path)))
+
+    return new_path
+
+
 def _fmt_album_path(album: Album, config: Config) -> Path:
     """Returns a formatted album directory according to the user configuration.
 
@@ -130,30 +175,12 @@ def _fmt_album_path(album: Album, config: Config) -> Path:
     library_path = Path(config.settings.move.library_path).expanduser()
     album_dir_name = f"{album.artist}/{album.title} ({album.year})"
 
-    album_path = library_path / album_dir_name
-
-    if config.settings.move.asciify_paths:
-        album_path = Path(unidecode(str(album_path)))
-
-    return album_path
+    return library_path / album_dir_name
 
 
 def _fmt_extra_path(extra: Extra, config: Config) -> Path:
-    """Returns a formatted extra path according to the user configuration.
-
-    Args:
-        extra: Extra used to format the path.
-        config: Moe config.
-
-    Returns:
-        Formatted extra path under its album path.
-    """
-    extra_path = extra.album_obj.path / extra.path.name
-
-    if config.settings.move.asciify_paths:
-        extra_path = Path(unidecode(str(extra_path)))
-
-    return extra_path
+    """Returns a formatted extra path according to the user configuration."""
+    return extra.album_obj.path / extra.path.name
 
 
 def _fmt_track_path(track: Track, config: Config) -> Path:
@@ -176,103 +203,108 @@ def _fmt_track_path(track: Track, config: Config) -> Path:
 
     track_filename = f"{track.track_num:02} - {track.title}{track.path.suffix}"
 
-    track_path = disc_dir / track_filename
-
-    if config.settings.move.asciify_paths:
-        track_path = Path(unidecode(str(track_path)))
-
-    return track_path
+    return disc_dir / track_filename
 
 
 ########################################################################################
 # Copy
 ########################################################################################
-def _copy_album(album: Album, dest: Path, config: Config):
-    """Copies an album to a given destination.
+def copy_item(item: LibItem, config: Config):
+    """Copies an item to a destination as determined by the user configuration.
+
+    Overwrites any existing files. Will create the destination if it does not already
+    exist.
+
+    Args:
+        item: Library item to copy.
+        config: Moe config.
+    """
+    if isinstance(item, Album):
+        _copy_album(item, config)
+    elif isinstance(item, (Extra, Track)):
+        _copy_file_item(item, config)
+
+
+def _copy_album(album: Album, config: Config):
+    """Copies an album to a destination as determined by the user configuration.
 
-    Overwrites any existing files. Will create ``dest`` if it does not already exist.
     Copying an album will also copy all of it's tracks and extras.
 
     Args:
         album: Album to copy
-        dest: Destination to copy the album to.
         config: Moe config.
     """
+    dest = fmt_item_path(album, config)
+
     log.info(f"Copying album from '{album.path}' to '{dest}'.")
     if album.path != dest:
         dest.mkdir(parents=True, exist_ok=True)
         album.path = dest
 
     for track in album.tracks:
-        _copy_track(track, _fmt_track_path(track, config))
+        _copy_file_item(track, config)
 
     for extra in album.extras:
-        _copy_extra(extra, _fmt_extra_path(extra, config))
+        _copy_file_item(extra, config)
 
 
-def _copy_track(track: Track, dest: Path):
-    """Copies a track to a given destination.
-
-    Overwrites any existing file at ``dest`` and creates any missing parent directories.
-
-    Args:
-        track: Track to copy.
-        dest: Destination file path to copy the track to.
-    """
-    if dest == track.path:
+def _copy_file_item(item: Union[Extra, Track], config: Config):
+    """Copies an extra or track to a destination as determined by the user config."""
+    dest = fmt_item_path(item, config)
+    if dest == item.path:
         return
 
-    log.info(f"Copying track from '{track.path}' to '{dest}'.")
+    log.info(f"Copying {type(item).__name__.lower()} from '{item.path}' to '{dest}'.")
     dest.parent.mkdir(parents=True, exist_ok=True)
-    shutil.copyfile(track.path, dest)
+    shutil.copyfile(item.path, dest)
 
-    track.path = dest
-
-
-def _copy_extra(extra: Extra, dest: Path):
-    """Copies an extra to a given destination.
-
-    Overwrites any existing file at ``dest`` and creates any missing parent directories.
-
-    Args:
-        extra: Extra to copy.
-        dest: Destination file path to copy the extra to.
-    """
-    if dest == extra.path:
-        return
-
-    log.info(f"Copying extra from '{extra.path}' to '{dest}'.")
-    dest.parent.mkdir(parents=True, exist_ok=True)
-    shutil.copyfile(extra.path, dest)
-
-    extra.path = dest
+    item.path = dest
 
 
 ########################################################################################
 # Move
 ########################################################################################
-def _move_album(album: Album, dest: Path, config: Config):
+def move_item(item: LibItem, config: Config):
+    """Moves an item to a destination as determined by the user configuration.
+
+    Overwrites any existing files. Will create the destination if it does not already
+    exist.
+
+    Args:
+        item: Library item to move.
+        config: Moe config.
+    """
+    if isinstance(item, Album):
+        _move_album(item, config)
+    elif isinstance(item, (Extra, Track)):
+        _move_file_item(item, config)
+
+
+def _move_album(album: Album, config: Config):
     """Moves an album to a given destination.
 
-    Overwrites any existing files. Will create ``dest`` if it does not already exist.
-    Moving an album will also move all of it's tracks and extras.
+    - Overwrites any existing files.
+    - Creates the destination if it does not already exist.
+    - Tracks and extras are also moved.
+    - Empty leftover directories will be removed.
 
     Args:
         album: Album to move.
-        dest: Destination to move the album to.
         config: Moe config.
     """
-    log.info(f"Moving album from '{album.path}' to '{dest}'.")
+    dest = fmt_item_path(album, config)
     old_album_dir = album.path
+
+    log.info(f"Moving album from '{album.path}' to '{dest}'.")
     if album.path != dest:
         dest.mkdir(parents=True, exist_ok=True)
         album.path = dest
 
     for track in album.tracks:
-        _move_track(track, _fmt_track_path(track, config))
+        _move_file_item(track, config)
 
     for extra in album.extras:
-        _move_extra(extra, _fmt_extra_path(extra, config))
+        _move_file_item(extra, config)
 
     # remove any empty leftover directories
     for old_child in old_album_dir.rglob("*"):
@@ -285,39 +317,14 @@ def _move_album(album: Album, dest: Path, config: Config):
             old_parent.rmdir()
 
 
-def _move_track(track: Track, dest: Path):
-    """Moves a track to a given destination.
-
-    Overwrites any existing file at ``dest`` and creates any missing parent directories.
-
-    Args:
-        track: Track to move.
-        dest: Destination file path to move the track to.
-    """
-    if dest == track.path:
+def _move_file_item(item: Union[Extra, Track], config: Config):
+    """Moves an extra or track to a destination as determined by the user config."""
+    dest = fmt_item_path(item, config)
+    if dest == item.path:
         return
 
-    log.info(f"Moving track from '{track.path}' to '{dest}'.")
+    log.info(f"Moving {type(item).__name__.lower()} from '{item.path}' to '{dest}'.")
     dest.parent.mkdir(parents=True, exist_ok=True)
-    track.path.replace(dest)
+    item.path.replace(dest)
 
-    track.path = dest
-
-
-def _move_extra(extra: Extra, dest: Path):
-    """Moves an extra to a given destination.
-
-    Overwrites any existing file at ``dest`` and creates any missing parent directories.
-
-    Args:
-        extra: Extra to move.
-        dest: Destination file path to move the extra to.
-    """
-    if dest == extra.path:
-        return
-
-    log.info(f"Moving extra from '{extra.path}' to '{dest}'.")
-    dest.parent.mkdir(parents=True, exist_ok=True)
-    extra.path.replace(dest)
-
-    extra.path = dest
+    item.path = dest
